==> moodle-3.5.zip: moodle/mod/assignment/lang/en/assignment.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'assignment', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   mod_assignment
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['assignment:addinstance'] = 'Add a new assignment';
$string['assignment:exportownsubmission'] = 'Export own submission';
$string['assignment:exportsubmission'] = 'Export submission';
$string['assignment:grade'] = 'Grade assignment';
$string['assignment:submit'] = 'Submit assignment';
$string['assignment:view'] = 'View assignment';
$string['assignmentneedsupgrade'] = 'The legacy "Assignment 2.2" activity has been disabled. Please request that your site administrator runs the assignment upgrade tool for all legacy assignments in this site.';
$string['messageprovider:assignment_updates'] = 'Assignment (2.2) notifications';
$string['assignmentdisabled'] = 'The legacy "Assignment 2.2" activity is disabled.';
$string['modulename'] = 'Assignment 2.2 (Disabled)';
$string['modulename_help'] = 'Legacy activity module that has been removed from Moodle.';
$string['modulenameplural'] = 'Assignments 2.2 (Disabled)';
$string['page-mod-assignment-x'] = 'Any assignment module page';
$string['page-mod-assignment-view'] = 'Assignment module main page';
$string['page-mod-assignment-submissions'] = 'Assignment module submission page';
$string['pluginname'] = 'Assignment 2.2 (Disabled)';
$string['upgradenotification'] = 'This activity is based on an older assignment module.';
$string['viewassignmentupgradetool'] = 'View the assignment upgrade tool';
$string['pluginadministration'] = 'Assignment 2.2 (Disabled) administration';
$string['privacy:markedsubmissionspath'] = 'markedsubmissions';
$string['privacy:submissionpath'] = 'submission';
$string['privacy:metadata:assignmentfilter'] = 'Filter preference of assignment submissions.';
$string['privacy:metadata:assignmentperpage'] = 'Number of assignment submissions shown per page preference.';
$string['privacy:metadata:assignmentmailinfo'] = 'Mail info preference for assignment submissions.';
$string['privacy:metadata:assignmentquickgrade'] = 'Quick grading preference for assignment submissions.';
$string['privacy:metadata:assignment_submissions'] = 'Assignment submissions associated with an assignment.';
$string['privacy:metadata:assignment_submissions:userid'] = 'The user ID submitting the assignment submission.';
$string['privacy:metadata:assignment_submissions:timecreated'] = 'The creation date/time of the assignment submission.';
$string['privacy:metadata:assignment_submissions:timemodified'] = 'The modification date/time of the assignment submission.';
$string['privacy:metadata:assignment_submissions:numfiles'] = 'The maximum number of files allowed for the assignment submission.';
$string['privacy:metadata:assignment_submissions:data1'] = 'The onlinetext submitted for the assignment submission.';
$string['privacy:metadata:assignment_submissions:data2'] = 'The tracked status for the assignment submission.';
$string['privacy:metadata:assignment_submissions:grade'] = 'The grade value awarded for the assignment submission.';
$string['privacy:metadata:assignment_submissions:submissioncomment'] = 'The submission comment accompanying the assignment submission.';
$string['privacy:metadata:assignment_submissions:teacher'] = 'The teacher user ID grading the assignment submission.';
$string['privacy:metadata:assignment_submissions:timemarked'] = 'The marking date/time of the assignment submission.';
$string['privacy:metadata:assignment_submissions:mailed'] = 'The mailed notification status of the assignment submission.';

==> moodle-3.7.7.zip: moodle/mod/assignment/lang/en/assignment.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'assignment', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   mod_assignment
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['assignment:addinstance'] = 'Add a new assignment';
$string['assignment:exportownsubmission'] = 'Export own submission';
$string['assignment:exportsubmission'] = 'Export submission';
$string['assignment:grade'] = 'Grade assignment';
$string['assignment:submit'] = 'Submit assignment';
$string['assignment:view'] = 'View assignment';
$string['assignmentneedsupgrade'] = 'The legacy "Assignment 2.2" activity has been removed.';
$string['messageprovider:assignment_updates'] = 'Assignment (2.2) notifications';
$string['assignmentdisabled'] = 'The legacy "Assignment 2.2" activity is disabled.';
$string['modulename'] = 'Assignment 2.2 (Disabled)';
$string['modulename_help'] = 'Legacy activity module that has been removed from Moodle.';
$string['modulenameplural'] = 'Assignments 2.2 (Disabled)';
$string['page-mod-assignment-x'] = 'Any assignment module page';
$string['page-mod-assignment-view'] = 'Assignment module main page';
$string['page-mod-assignment-submissions'] = 'Assignment module submission page';
$string['pluginname'] = 'Assignment 2.2 (Disabled)';
$string['upgradenotification'] = 'This activity is based on an older assignment module.';
$string['pluginadministration'] = 'Assignment 2.2 (Disabled) administration';
$string['privacy:markedsubmissionspath'] = 'markedsubmissions';
$string['privacy:submissionpath'] = 'submission';
$string['privacy:metadata:assignmentfilter'] = 'Filter preference of assignment submissions.';
$string['privacy:metadata:assignmentperpage'] = 'Number of assignment submissions shown per page preference.';
$string['privacy:metadata:assignmentmailinfo'] = 'Mail info preference for assignment submissions.';
$string['privacy:metadata:assignmentquickgrade'] = 'Quick grading preference for assignment submissions.';
$string['privacy:metadata:assignment_submissions'] = 'Assignment submissions associated with an assignment.';
$string['privacy:metadata:assignment_submissions:userid'] = 'The user ID submitting the assignment submission.';
$string['privacy:metadata:assignment_submissions:timecreated'] = 'The creation date/time of the assignment submission.';
$string['privacy:metadata:assignment_submissions:timemodified'] = 'The modification date/time of the assignment submission.';
$string['privacy:metadata:assignment_submissions:numfiles'] = 'The maximum number of files allowed for the assignment submission.';
$string['privacy:metadata:assignment_submissions:data1'] = 'The onlinetext submitted for the assignment submission.';
$string['privacy:metadata:assignment_submissions:data2'] = 'The tracked status for the assignment submission.';
$string['privacy:metadata:assignment_submissions:grade'] = 'The grade value awarded for the assignment submission.';
$string['privacy:metadata:assignment_submissions:submissioncomment'] = 'The submission comment accompanying the assignment submission.';
$string['privacy:metadata:assignment_submissions:teacher'] = 'The teacher user ID grading the assignment submission.';
$string['privacy:metadata:assignment_submissions:timemarked'] = 'The marking date/time of the assignment submission.';
$string['privacy:metadata:assignment_submissions:mailed'] = 'The mailed notification status of the assignment submission.';
